@@ -3,6 +3,8 @@ package File::Format::CRD::Reader;
 use warnings;
 use strict;
 
+use 5.008;
+
 use Carp;
 
 use Encode;
@@ -15,11 +17,13 @@ File::Format::CRD::Reader - read Windows .CRD files.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.0.2
 
 =cut
 
-our $VERSION = '0.0.1';
+use vars qw($VERSION);
+
+$VERSION = '0.0.1';
 
 =head1 SYNOPSIS
 
@@ -29,7 +33,7 @@ our $VERSION = '0.0.1';
 
     while (my $card = $reader->get_next_card({encoding => "windows-1255"}))
     {
-        print "Title = " , $card->{'title'}, "\nBody = <<<\n", 
+        print "Title = " , $card->{'title'}, "\nBody = <<<\n",
             $card->{'body'}, "\n>>>\n\n";
     }
 
@@ -105,7 +109,7 @@ sub _init
 
     if ($magic ne "MGC")
     {
-        Carp::confess("Could not find magic number in file.");        
+        Carp::confess("Could not find magic number in file.");
     }
 
     my $n_cards = $self->_read_short(3);
@@ -167,7 +171,7 @@ and a hash-ref like that upon success:
         'body' => "Body of card\nHello",
     }
 
-The encoding parameter C<'encoding'> can be used to decode the card using a 
+The encoding parameter C<'encoding'> can be used to decode the card using a
 certain encoding.
 
 =cut
